@@ -1,3 +1,4 @@
+/// <reference path="./lib/fresh.d.ts" />
 // Markdown Compose Mode Plugin
 // Provides compose mode for Markdown documents with:
 // - Soft wrapping at a configurable width
@@ -6,6 +7,8 @@
 //
 // Syntax highlighting is handled by the TextMate grammar (built-in to the editor)
 // This plugin only adds the compose mode layout features.
+const editor = getEditor();
+
 
 interface MarkdownConfig {
   composeWidth: number;
@@ -22,23 +25,6 @@ const config: MarkdownConfig = {
 // Track buffers in compose mode (explicit toggle)
 const composeBuffers = new Set<number>();
 
-// Types match the Rust ViewTokenWire structure
-interface ViewTokenWire {
-  source_offset: number | null;
-  kind: ViewTokenWireKind;
-}
-
-type ViewTokenWireKind =
-  | { Text: string }
-  | "Newline"
-  | "Space"
-  | "Break";
-
-interface LayoutHints {
-  compose_width?: number | null;
-  column_guides?: number[] | null;
-}
-
 // =============================================================================
 // Block-based parser for hanging indent support
 // =============================================================================
@@ -348,7 +334,7 @@ function disableMarkdownCompose(bufferId: number): void {
     editor.setLineNumbers(bufferId, true);
 
     // Clear view transform to return to normal rendering
-    editor.clearViewTransform(bufferId);
+    editor.clearViewTransform(bufferId, null);
 
     editor.refreshLines(bufferId);
     editor.debug(`Markdown compose disabled for buffer ${bufferId}`);
@@ -364,18 +350,18 @@ globalThis.markdownToggleCompose = function(): void {
 
   // Only work with markdown files
   if (!info.path.endsWith('.md') && !info.path.endsWith('.markdown')) {
-    editor.setStatus("Not a Markdown file");
+    editor.setStatus(editor.t("status.not_markdown_file"));
     return;
   }
 
   if (composeBuffers.has(bufferId)) {
     disableMarkdownCompose(bufferId);
-    editor.setStatus("Markdown Compose: OFF");
+    editor.setStatus(editor.t("status.compose_off"));
   } else {
     enableMarkdownCompose(bufferId);
     // Trigger a re-render to apply the transform
     editor.refreshLines(bufferId);
-    editor.setStatus("Markdown Compose: ON (soft breaks, centered)");
+    editor.setStatus(editor.t("status.compose_on"));
   }
 };
 
@@ -549,10 +535,10 @@ globalThis.onMarkdownViewTransform = function(data: {
     data.viewport_start
   );
 
-  // Submit the transformed tokens - keep compose_width for margins/centering
+  // Submit the transformed tokens - keep composeWidth for margins/centering
   const layoutHints: LayoutHints = {
-    compose_width: config.composeWidth,
-    column_guides: null,
+    composeWidth: config.composeWidth,
+    columnGuides: null,
   };
 
   editor.submitViewTransform(
@@ -577,12 +563,12 @@ editor.on("prompt_confirmed", "onMarkdownComposeWidthConfirmed");
 
 // Set compose width command - starts interactive prompt
 globalThis.markdownSetComposeWidth = function(): void {
-  editor.startPrompt("Compose width: ", "markdown-compose-width");
+  editor.startPrompt(editor.t("prompt.compose_width"), "markdown-compose-width");
   editor.setPromptSuggestions([
-    { text: "60", description: "Narrow - good for side panels" },
-    { text: "72", description: "Classic - traditional terminal width" },
-    { text: "80", description: "Standard - default width" },
-    { text: "100", description: "Wide - more content per line" },
+    { text: "60", description: editor.t("suggestion.narrow") },
+    { text: "72", description: editor.t("suggestion.classic") },
+    { text: "80", description: editor.t("suggestion.standard") },
+    { text: "100", description: editor.t("suggestion.wide") },
   ]);
 };
 
@@ -596,7 +582,7 @@ globalThis.onMarkdownComposeWidthConfirmed = function(args: {
   const width = parseInt(args.text, 10);
   if (!isNaN(width) && width > 20 && width < 300) {
     config.composeWidth = width;
-    editor.setStatus(`Markdown compose width set to ${width}`);
+    editor.setStatus(editor.t("status.width_set", { width: String(width) }));
 
     // Re-process active buffer if in compose mode
     const bufferId = editor.getActiveBufferId();
@@ -604,25 +590,24 @@ globalThis.onMarkdownComposeWidthConfirmed = function(args: {
       editor.refreshLines(bufferId);  // Trigger re-transform
     }
   } else {
-    editor.setStatus("Invalid width - must be between 20 and 300");
+    editor.setStatus(editor.t("status.invalid_width"));
   }
 };
 
 // Register commands
 editor.registerCommand(
-  "Markdown: Toggle Compose",
-  "Toggle compose mode (soft wrapping, centered margins)",
+  "%cmd.toggle_compose",
+  "%cmd.toggle_compose_desc",
   "markdownToggleCompose",
   "normal"
 );
 
 editor.registerCommand(
-  "Markdown: Set Compose Width",
-  "Set the width for compose mode wrapping and margins",
+  "%cmd.set_compose_width",
+  "%cmd.set_compose_width_desc",
   "markdownSetComposeWidth",
   "normal"
 );
 
 // Initialization
 editor.debug("Markdown Compose plugin loaded - use 'Markdown: Toggle Compose' command");
-editor.setStatus("Markdown plugin ready");
